@@ -378,8 +378,8 @@ class MBIODeviceBelimoP22RTH(MBIODeviceBelimo):
 
         r=self.readInputRegisters(21, 2)
         if r:
-            if self.config.spmodeabsolute:
-                if self.config.setpoint:
+            if self.config.setpoint:
+                if self.config.spmodeabsolute:
                     self.spT.updateValue(r[0]/100)
                     v=self.spT.value-self.config.spzero
                     self.spTX.updateValue(v)
@@ -400,13 +400,15 @@ class MBIODeviceBelimoP22RTH(MBIODeviceBelimo):
                         fanauto=False
                     self.fanAuto.updateValue(fanauto)
 
-        if not self.config.spmodeabsolute:
-            r=self.readInputRegisters(36, 1)
-            if r:
-                decoder=self.decoderFromRegisters(r)
-                self.spT.updateValue(decoder.int()/100)
-                v=self.config.spzero+self.spT.value
-                self.spTX.updateValue(v)
+        if self.config.setpoint:
+            if not self.config.spmodeabsolute:
+                r=self.readInputRegisters(36, 1)
+                if r:
+                    decoder=self.decoderFromRegisters(r)
+                    v=decoder.int()/100
+                    self.spT.updateValue(v)
+                    v=self.config.spzero+self.spT.value
+                    self.spTX.updateValue(v)
 
         r=self.readInputRegisters(33, 1)
         if r:
