@@ -410,6 +410,12 @@ class MBIOGateway(object):
                             device=MBIODeviceSensortecELD(self, address, xml=xml)
                         except:
                             self.logger.exception('device')
+                    elif model=='el':
+                        try:
+                            from .sensortec import MBIODeviceSensortecEL
+                            device=MBIODeviceSensortecEL(self, address, xml=xml)
+                        except:
+                            self.logger.exception('device')
 
                 elif 'isma' in vendor:
                     if '4i4oh' in model:
