@@ -79,6 +79,10 @@ class MBIO(object):
     def logger(self):
         return self._logger
 
+    @property
+    def wserver(self):
+        return self._wserver
+
     @property
     def parent(self):
         return None
@@ -234,7 +238,7 @@ class MBIO(object):
 
             port=config.getInt('webserver', 8000)
             if port>1024 and self._interface:
-                self._wserver=TemporaryWebServer('/tmp/wserver', port=port, host=self._interface)
+                self._wserver=TemporaryWebServer('/tmp/wserver', port=port, host=self._interface, logger=self.logger)
 
             self.loadGateways(config)
 
@@ -365,6 +369,13 @@ class MBIO(object):
                 except:
                     self.logger.exception('task')
 
+            for item in config.children('monitor'):
+                try:
+                    from .wsmonitor import MBIOWsMonitor
+                    MBIOWsMonitor(self, item.get('name'), xml=item)
+                except:
+                    self.logger.exception('task')
+
             notifiers=config.child('notifiers')
             if notifiers:
                 targets=notifiers.children('target')
@@ -749,6 +760,7 @@ class MBIO(object):
 
     def wsExposeFile(self, fname, alias=None, timeout=600):
         if self._wserver and self._wserver.url():
+            self.logger.info("Exposing file %s (alias %s, timeout %ds) to the internal WebServer system" % (fname, alias, timeout))
             return self._wserver.importFile(fname, alias, timeout)
 
     def wsGetFileContent(self, fname):
