@@ -146,8 +146,11 @@ class MBIODeviceSensortecELD(MBIODevice):
             v |= (0x1 << 4)
         if self.config.icons:
             v |= (0x1 << 5)
-        if self.config.iaq and (not self.config.co2hidden or not self.config.covhidden):
-            v |= (0x1 << 6)
+        if self.config.iaq:
+            if self.config.co2 and not self.config.co2hidden:
+                v |= (0x1 << 6)
+            if self.config.cov and not self.config.covhidden:
+                v |= (0x1 << 6)
         self.writeRegistersIfChanged(20, v)
 
         self.writeRegistersIfChanged(14, self.config.toffset*100)
